Class: ScormEngine::Models::Destination
- Defined in:
- lib/scorm_engine/models/destination.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
TODO: Not sure we want this to be settable.
-
#name ⇒ Object
TODO: Not sure we want this to be settable.
Class Method Summary collapse
Methods inherited from Base
Instance Attribute Details
#id ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
7 8 9 |
# File 'lib/scorm_engine/models/destination.rb', line 7 def id @id end |
#name ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
7 8 9 |
# File 'lib/scorm_engine/models/destination.rb', line 7 def name @name end |
Class Method Details
.new_from_api(options = {}) ⇒ Object
9 10 11 12 13 14 15 16 17 18 19 20 21 |
# File 'lib/scorm_engine/models/destination.rb', line 9 def self.new_from_api( = {}) this = new this. = .dup this.id = ["id"] # get_destinations (plural) returns values in a nested 'data' field. # get_destination (singular) does not. data = ["data"] || this.name = data["name"] this end |