Class: ScormEngine::Models::Learner
- Defined in:
- lib/scorm_engine/models/learner.rb
Instance Attribute Summary collapse
-
#first_name ⇒ Object
TODO: Not sure we want this to be settable.
-
#id ⇒ Object
TODO: Not sure we want this to be settable.
-
#last_name ⇒ Object
TODO: Not sure we want this to be settable.
Class Method Summary collapse
Methods inherited from Base
Instance Attribute Details
#first_name ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
7 8 9 |
# File 'lib/scorm_engine/models/learner.rb', line 7 def first_name @first_name end |
#id ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
7 8 9 |
# File 'lib/scorm_engine/models/learner.rb', line 7 def id @id end |
#last_name ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
7 8 9 |
# File 'lib/scorm_engine/models/learner.rb', line 7 def last_name @last_name end |
Class Method Details
.new_from_api(options = {}) ⇒ Object
9 10 11 12 13 14 15 16 17 18 |
# File 'lib/scorm_engine/models/learner.rb', line 9 def self.new_from_api( = {}) this = new this. = .dup this.id = ["id"] this.first_name = ["firstName"] this.last_name = ["lastName"] this end |