Class: ScormEngine::Models::Registration
- Defined in:
- lib/scorm_engine/models/registration.rb
Instance Attribute Summary collapse
-
#activity_details ⇒ Object
TODO: Not sure we want this to be settable.
-
#completed_date ⇒ Object
TODO: Not sure we want this to be settable.
-
#course ⇒ Object
TODO: Not sure we want this to be settable.
-
#created_date ⇒ Object
TODO: Not sure we want this to be settable.
-
#first_access_date ⇒ Object
TODO: Not sure we want this to be settable.
-
#id ⇒ Object
TODO: Not sure we want this to be settable.
-
#instance ⇒ Object
TODO: Not sure we want this to be settable.
-
#last_access_date ⇒ Object
TODO: Not sure we want this to be settable.
-
#learner ⇒ Object
TODO: Not sure we want this to be settable.
-
#registration_completion ⇒ String
Has this registration been completed?.
-
#registration_completion_amount ⇒ Float
A decimal value between 0 and 1 representing the percentage of this course that the learner has completed so far, if known.
-
#registration_success ⇒ String
Has this registration been passed?.
-
#score ⇒ Object
TODO: Not sure we want this to be settable.
-
#total_seconds_tracked ⇒ Object
TODO: Not sure we want this to be settable.
-
#updated ⇒ Object
TODO: Not sure we want this to be settable.
Class Method Summary collapse
-
.get_completed_at_from_api(options = {}) ⇒ Time
Extract and normalize the completed date from the API options.
-
.get_score_from_api(options = {}) ⇒ Float
Extract and normalize the scaled passing score from the API options.
- .new_from_api(options = {}) ⇒ Object
Instance Method Summary collapse
-
#complete? ⇒ Boolean
Has this registration been completed?.
-
#failed? ⇒ Boolean
Has this registration failed?.
-
#incomplete? ⇒ Boolean
Is this registration incomplete?.
-
#passed? ⇒ Boolean
Has this registration been passed?.
Methods inherited from Base
Instance Attribute Details
#activity_details ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def activity_details @activity_details end |
#completed_date ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def completed_date @completed_date end |
#course ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def course @course end |
#created_date ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def created_date @created_date end |
#first_access_date ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def first_access_date @first_access_date end |
#id ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def id @id end |
#instance ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def instance @instance end |
#last_access_date ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def last_access_date @last_access_date end |
#learner ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def learner @learner end |
#registration_completion ⇒ String
Has this registration been completed?
23 24 25 |
# File 'lib/scorm_engine/models/registration.rb', line 23 def registration_completion @registration_completion end |
#registration_completion_amount ⇒ Float
A decimal value between 0 and 1 representing the percentage of this course that the learner has completed so far, if known. Note: for learning standards other than SCORM 2004 4th Edition, this value is based on the percentage of activities completed/passed. This means that single-activity courses in those standards will always return either 0 or 1.
38 39 40 |
# File 'lib/scorm_engine/models/registration.rb', line 38 def registration_completion_amount @registration_completion_amount end |
#registration_success ⇒ String
Has this registration been passed?
28 29 30 |
# File 'lib/scorm_engine/models/registration.rb', line 28 def registration_success @registration_success end |
#score ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def score @score end |
#total_seconds_tracked ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def total_seconds_tracked @total_seconds_tracked end |
#updated ⇒ Object
TODO: Not sure we want this to be settable. Will depend on how we go about creating/updating records. For now it makes it easier to create instances from API options hash.
16 17 18 |
# File 'lib/scorm_engine/models/registration.rb', line 16 def updated @updated end |
Class Method Details
.get_completed_at_from_api(options = {}) ⇒ Time
Extract and normalize the completed date from the API options.
134 135 136 137 138 139 |
# File 'lib/scorm_engine/models/registration.rb', line 134 def self.get_completed_at_from_api( = {}) completed_date = ["completedDate"] completed_date ||= .fetch("score", {})["completedDate"] return if completed_date.nil? Time.parse(completed_date) end |
.get_score_from_api(options = {}) ⇒ Float
Extract and normalize the scaled passing score from the API options.
119 120 121 122 123 |
# File 'lib/scorm_engine/models/registration.rb', line 119 def self.get_score_from_api( = {}) score = .fetch("score", {})["scaled"] return if score.nil? score.to_f end |
.new_from_api(options = {}) ⇒ Object
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/scorm_engine/models/registration.rb', line 40 def self.new_from_api( = {}) this = new this. = .dup this.id = ["id"] this.instance = ["instance"] this.updated = Time.parse(["updated"]) if .key?("updated") this.registration_completion = ["registrationCompletion"] this.registration_success = ["registrationSuccess"] this.total_seconds_tracked = ["totalSecondsTracked"] this.first_access_date = Time.parse(["firstAccessDate"]) if .key?("firstAccessDate") this.last_access_date = Time.parse(["lastAccessDate"]) if .key?("lastAccessDate") this.created_date = Time.parse(["createdDate"]) if .key?("createdDate") this.updated = Time.parse(["updated"]) if .key?("updated") this.registration_completion_amount = ["registrationCompletionAmount"].to_f # Sometimes it returns "NaN" this.score = get_score_from_api() this.completed_date = get_completed_at_from_api() this.activity_details = RegistrationActivityDetail.new_from_api(["activityDetails"]) if .key?("activityDetails") this.course = Course.new_from_api(["course"]) if .key?("course") this.learner = Learner.new_from_api(["learner"]) if .key?("learner") this end |
Instance Method Details
#complete? ⇒ Boolean
Has this registration been completed?
72 73 74 75 |
# File 'lib/scorm_engine/models/registration.rb', line 72 def complete? return nil if registration_completion == "UNKNOWN" registration_completion == "COMPLETED" end |
#failed? ⇒ Boolean
Has this registration failed?
105 106 107 108 |
# File 'lib/scorm_engine/models/registration.rb', line 105 def failed? return nil if registration_success == "Unknown" registration_success == "Failed" end |
#incomplete? ⇒ Boolean
Is this registration incomplete?
83 84 85 86 |
# File 'lib/scorm_engine/models/registration.rb', line 83 def incomplete? return nil if registration_completion == "UNKNOWN" registration_completion == "INCOMPLETE" end |
#passed? ⇒ Boolean
Has this registration been passed?
94 95 96 97 |
# File 'lib/scorm_engine/models/registration.rb', line 94 def passed? return nil if registration_success == "Unknown" registration_success == "Passed" end |